@@ -22,12 +22,10 @@ logo = """
                                                                    
 """
 
-welcome = """
-Welcome to Arkitekt. Arkitekt is a bioimage analysis framework for building beautiful 
-and fast (serverless) APIs around your python code. It is buid on top of composable 
-packages like mikro, fluss and rekuest, which allow you to build simple apps with ease.
-"""
-
+welcome = "Welcome to Arkitekt. Arkitekt is a bioimage analysis framework for building"\
+" beautiful and fast (serverless) APIs around your python code. It is buid on top of "\
+"composable packages like mikro, fluss and rekuest, which allow you to build simple"\
+" apps with ease."
 
 
 
@@ -328,10 +326,11 @@ def port(version, dockerfile, nopush, tag, runtime, nodefs, builder, entrypoint)
         raise click.ClickException("You cannot deploy a dev version. Please change the version in your manifest. Or use the --version flag.")
 
     with console.status("Searching username"):
-        docker_info = subprocess.check_output(["docker", "info"]).decode("utf-8")
-        username = search_username_in_docker_info(docker_info)
-        if not username:
-            raise click.ClickException("Could not find username in docker info. Have you logged in? Try 'docker login'")
+        try:
+            docker_info = subprocess.check_output(["docker", "info"]).decode("utf-8")
+            username = search_username_in_docker_info(docker_info)r
+            if not username:
+                username = click.prompt("Could not find username in docker info. Please provide your docker username")
 
 
     tag = tag or click.prompt("The tag to use", default=f"{username}/{manifest.identifier}:{version}")     
@@ -367,9 +366,9 @@ def prompt_scopes():
     used_scopes = []
     scopes = compile_scopes()
 
-    scope_text = "\n\n[white]Every arkitekt app is assigned specific permissions to access data and interact with the" \
-                  "platform. These permissions are called scopes, and are additional safeguard to the user permissions" \
-                  "that are already in place. You can find a list of all available scopes "\
+    scope_text = "\n\n[white]Every arkitekt app is assigned specific permissions to access data and interact with the " \
+                  "platform. These permissions are called scopes, and are additional safeguard to the user permissions. " \
+                  "You can find a list of all available scopes "\
                 "[link=https://jhnnsrs.github.io/security/scopes.html]here[/link]\n\n" \
                  "Please try to use as [b]few[/b] scopes as possible" \
 
@@ -378,8 +377,8 @@ def prompt_scopes():
 
     panel = Panel("Let's talk permissions" + scope_text, title_align="center", border_style="green", style="green")
     console.print(panel)
-    while click.confirm("Do you want to add a scope?"):
-        scope = click.prompt("The scope to use", type=click.Choice(scopes), show_choices=True)
+    while click.confirm(" Do you want to add a scope?"):
+        scope = click.prompt(" The scope to use", type=click.Choice(scopes), show_choices=True)
         used_scopes.append(scope)
 
     return used_scopes
@@ -441,6 +440,8 @@ def init(identifier, version, author, entrypoint, builder, scopes, template):
 
 
     write_manifest(manifest)
+    md = Panel(f"{manifest.identifier} was successfully initialized\n\n" + "[not bold white]We are excited to see what you come up with!",  border_style="green", style="green")
+    console.print(md)
 
 
 @cli.command()
